# 1 "init_params.F"
c =====================================================================
c
c     SUBROUTINE INIT_PARAMS
c 
c     PURPOSE: this routine initializes the values of the various
c                parameters
c
c     VARIABLES:
c 
c     IN : 
c
c     OUT: 
c 
c     REVISION:
c
c     date     author  remarks
c   
c     29.08.01   ng    first implementation, used to be an include
c                        file with data statements
c
c =====================================================================
c
      subroutine init_params(incl_adv,plot_out,
     $     tstart,tend,ts,
     $     pv_relship,D_fco2_corr,sg_D_fco2_corr,
     $     gasex_fact,sg_gasex_fact,ws_coeff,
     $     h_coeff,ent_scheme,const_kz,kz_const,
     $     const_vertgrad,dCdz_const,D_dcdz,sg_D_dcdz,
     $     h_th,c_th,dc13_th,
     $     const_lent,lent_const,sg_lent_const,dlent_dh,sg_dlent_dh,
     $     ddC13_dC_bml,sg_ddC13_dC_bml,
     $     ent_fact,diff_fact,sg_diff_fact,sg_ent_fact,
     $     dC_dh,sg_dC_dh,ddC13_dh,sg_ddC13_dh,u,sg_u,
     $     D_dc13_org,sg_D_dc13_org) 
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 43 "init_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 44 "init_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 45 "init_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 46 "init_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 47 "init_params.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 48 "init_params.F" 2
c     
c --------------------------------------------------------------------
c     statement
c --------------------------------------------------------------------
c     
      write(*,*) '--INIT_PARAMS: initializing parameters...'
c     
c --------------------------------------------------------------------
c     general parameters
c --------------------------------------------------------------------
c     
      incl_adv = .false. 
      plot_out = .false. 
c     
c --------------------------------------------------------------------
c     simulation control parameters
c --------------------------------------------------------------------
c     
      tstart = 1983.0d0
      tend = 2001.d0
      ts = 0.0025d0 
c     
c --------------------------------------------------------------------
c     air-sea gasexchange parameters
c --------------------------------------------------------------------
c     
      pv_relship = 'wa'
c
      D_fco2_corr = 0.0d0 
c      sg_D_fco2_corr = 10.d0 
      sg_D_fco2_corr = 1.d0 
c
      gasex_fact = 1.0d0 
      sg_gasex_fact = 0.1d0
c
      ws_coeff = 'ih'
c     
c --------------------------------------------------------------------
c     diffusion - entrainment parameters
c --------------------------------------------------------------------
c     h_coeff = 'a'

      ent_scheme = 'ma'
      const_kz = .false.
c
      kz_const = 2.d-5
      sg_kz_const = 1.d-5
c
      const_vertgrad = .false.
      dCdz_const = 0.45d0
c
      D_dcdz = 0.0d0
      sg_D_dcdz = 0.1d0
c
      h_th    = 200.d0
      c_th    = 2066.31d0
      dc13_th = 1.28d0
c
      const_lent = .true.
      lent_const = 12.d0
c      sg_lent_const = 6.d0
      sg_lent_const = 3.d0
c
      dlent_dh = 0.11
      sg_dlent_dh = 0.4
c
      ddC13_dC_bml = -0.0048d0 
      sg_ddC13_dC_bml = 0.0008d0
c
      ent_fact = 1.0d0
      diff_fact = 1.0d0
      sg_diff_fact = 0.5d0
      sg_ent_fact = 0.5d0
c     
c --------------------------------------------------------------------
c     advection parameters
c --------------------------------------------------------------------
c     
      dC_dh = 1.1d-5
      sg_dC_dh = 0.3d-5
c
      ddC13_dh = -1.0d-7
      sg_ddC13_dh = 1.0d-7
c
      u = 0.05d0
      sg_u = 0.05d0
c     
c --------------------------------------------------------------------
c     net community production parameters
c --------------------------------------------------------------------
c     
      D_dc13_org = 0.0d0
      sg_D_dc13_org = 3.0d0
c     
c --------------------------------------------------------------------
c     return to calling routine
c --------------------------------------------------------------------
c     
      return
      end
