# 1 "init_val.F"
c =====================================================================
c
c     SUBROUTINE INIT_VAL
c 
c     PURPOSE: this routine initializes the values needed for
c                doing the simulation
c
c     VARIABLES:
c 
c     IN : time         : actual time
c          dc13_coeff      : character specifying which dC13 coefficients
c                              are used       
c          h_coeff      : character specifying which coefficients for
c
c     OUT: C_old        : mixed layer C concentration at time t
c          C13_old      : mixed layer C13 concentration at time t
c          h_old        : mixed layer depth at time t
c          C_sim        : mixed layer C concentration at start time
c          error        : logical
c 
c     REVISION:
c
c     date     author  remarks
c   
c     31.07.96   ng    first implementation
c      5.09.96   ng    included possibility to do backwards integration
c     15.10.99   ng    adapted for interannual variability run, time
c                         is now in years,added error
c     07.06.00   ng    avoid h less than 15
c
c =====================================================================
c
      subroutine init_val(time,dc13_coeff,h_coeff,
     $     C_old,c13_old,h_old,c_sim,error)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 43 "init_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 44 "init_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 45 "init_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 46 "init_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h" 1
c===================== include file harm_coeff.h =========================
c
c coefficients of the harmonic fits to the input data
c
c REVISIONS:
c
c date     author    remarks
c
c 30.7.96  ng        first fits (not yet checked)
c                      for wind-speed : still using old fits
c 10.9.96  ng        updated coefficients, using only coeff which
c                      are significant at the 5% level (tested by
c                      Student t-test)
c                    changes include temperature,ddic_dz and dc13_atm
c 17.10.99 ng        adapted for interannual variability runs at BERM
c 06.06.00 ng        added new coefficients based on combined BERM/BATS
c                      data set
c 24.08.01 ng        added new coefficients for 1983-2001 (BERM/BATS)
c 03.10.01 bx        added new coefficients for HAWI_harm
c 16.10.01 bx        added new coefficients for HAWI_hali
c 03.05.02 ng        added new coefficients for 1983 to 2002 (BERM/BATS)
c 10.01.03 bx        changed coefficients for HAWI_hali to detrended
c                      values for c_pco2a and later in following list
c 13.05.03 bx        added new coefficients for 1
c 16.20.03 bx        added new coefficients for MUN_hali
c
c variables:
c
c name        type   description
c-------------------------------------------------------------------------
c
c c_temp      dp  a   coefficients for mixed layer temperature    [deg C]
c c_sal       dp  a   coefficients for mixed layer salinity       [psu]
c c_sdic      dp  a   coefficients for mixed layer normalized C   [umol/kg]
c c_salk      dp  a   coefficients for mixed layer normalized Alk [umol/kg]
c c_dc13      dp  a   coefficients for mixed layer dC13           [permil]
c c_fco2_o    dp  a   coefficients for mixed layer fCO2           [ppm]
c c_pco2a     dp  a   coefficients for atm pCO2                   [ppm]
c c_dc13a     dp  a   coefficients for atm dC13                   [per mil]
c c_ws        dp  a   coefficients for wind wind speed            [m s-1]
c                          fit                                    [m2 s-2]
c c_h         dp  a   coefficients for mld                        [m]
c c_dCdz      dp  a   coefficients for dC/dz                      [umol/kg m]
c c_kz_var    dp  a   coefficients for seasonally varying kz      [m2 s-1]
c
c===========================================================================
c
      double precision c_temp(7),c_sal(7)
      double precision c_sdic(7),c_salk(7)
      double precision c_dc13(7),c_fco2_o(7)
      double precision c_pco2a(7),c_dc13a(7)
      double precision c_h(7)
      double precision c_dCdz(7)
      double precision c_kz_var(7),c_ws(7)

# 254 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h"

c     
c --------------------------------------------------------------------
c     Hawaii station data (1988-2001) - without linear trend
c       updated with data for pCO2a and c13a from CDRG on 13MAY03
c       and for 2002 CDRG ocean data on 21MAY03 BX
c --------------------------------------------------------------------

      data c_temp    / 0.24812d+2,
     $                -0.14119d+1,-0.57805d+0,-0.10165d+0,-0.88825d-1,
     $                 0.67235d-1,-0.10919d+0/
c
      data c_sal     / 0.35024d+2,
     $                -0.31043d-1, 0.41717d-1,-0.81345d-2,-0.26381d-1,
     $                -0.58158d-3,-0.55224d-2/
c
      data c_sdic    / 0.19703d+4,  !@salinity 35
     $                 0.68715d+1, 0.36846d+0, 0.45182d+0, 0.73481d+0,
     $                -0.22355E+0, 0.82337d+0/
c






      data c_dc13    / 0.14013d+1,
     $                -0.34983d-1,-0.95196d-2,-0.12653d-2,-0.43141d-2,
     $                -0.52941d-2,-0.85351d-2/
c

      data c_salk    / 0.23023d+4,  !@salinity 35
     $                 0.33544d+0,-0.19139d+0,-0.10066d+0,-0.76999d-1,
     $                 0.20537E+0, 0.47237d+0/
c
      data c_fco2_o /  0.33502d+3,  !from hawi analysis as a start - not relevant
c                                              if fco2 is calculated online!!!! no update!
     $                -0.11403d+2,-0.67576d+1,-0.13061d+1,-0.23050d+1,
     $                -0.13238d+1, 0.36076d+0/
c
      data c_pco2a  /  0.36092d+3,  ! xCO2 values from Cape Kumakahi - CDRG monthly mean
c$$$c                                              data until DEC2001 - update 13MAY03
     $                 0.36140d+1,-0.16714d+0,-0.93759d+0, 0.69224d+0,
     $                 0.71550d-1,-0.12653d+0/
c$$$      data c_pco2a  /  0.35186d+3,  ! pCO2 values from Cape Kumakahi - CMDL monthly mean
c$$$c                                              data until DEC2001 - just to test changes
c$$$c                                              due to altered dc13a
c$$$     $                 0.42023d+1, 0.35496d+0,-0.89050d+0, 0.71105d+0,
c$$$     $                 0.51808d-2,-0.88914d-1/
c
      data c_dc13a  / -0.79609d+1, ! values from Cape Kumakahi - CDRG monthly mean
c                                              data unitl DEC2001 - update 13MAY03
     $                -0.18599d+0, 0.24384d-2, 0.55990d-1,-0.26230d-1,
     $                -0.71237d-2, 0.74483d-2/
c
      data c_kz_var  / 0.17543d-4, ! from mld analysis - ctd data until 2001 with stdev
c                                              data from NOV1988 to DEC2001 - update 10JAN03
     $                 0.10960d-4, 0.20921d-5, 0.24164d-5,-0.50949d-5,
     $                -0.11143d-5, 0.64844d-6/
c
cBX     updated 10JAN03 for data from CTD-MLD - data from 1989 until 1999
      data c_dCdz    / 0.64473d+0, ! calculated from HOT data set
     $                -0.18951d+0, 0.12957d+0, 0.60458d-2, 0.94335d-1,
     $                -0.52134d-1,-0.17519d-1/
# 417 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h"

c
      
c     
c --------------------------------------------------------------------
c     unspecific coefficients or user able to choose interactively
c --------------------------------------------------------------------
c
# 437 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h"

c NCEP monthly reanalysis data 88-99 - without linear trend
cBX   update incl. 2001 data - 10JAN03
c
      data c_ws   / 0.74433d+1,
     $              0.63257d-1,-0.59071d+0,-0.11794d+0, 0.30269d+0,
     $             -0.42803d+0,-0.16067d+0/
# 461 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h"

c
# 476 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h"

c mld data calculated from HOT data set - without linear trend
cBX   ctd data calculated with standard deviation
cBX   update incl. 2001 data - 10JAN03
c
      data c_h     / 0.60294d+2,
     $              -0.31338d+1, 0.25574d+2, 0.22713d+1, 0.11109d+2,
     $              -0.13393d+1, 0.36606d+1/
# 504 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/harm_coeff.h"


# 47 "init_val.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 48 "init_val.F" 2
      logical error
c
c ---------------------------------------------------------------------
c     external functions
c ---------------------------------------------------------------------
c
      double precision harmonic,delta_to_c13,spline
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      double precision dc13_tmp
       
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      C_old = harmonic(time,c_sdic,7) + spline(time,'sdic ',error)
c
      dc13_tmp = harmonic(time,c_dc13,7) + spline(time,'dc13 ',error)
      c13_old = delta_to_c13(dc13_tmp,C_old)
c
      h_old = harmonic(time,c_h,7) + spline(time,'h    ',error)
c
      if (h_old .lt. 15.) then
         h_old = 15.
      endif

c
      C_sim(1) = C_old
c
      if (error) goto 9900
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c              
 9900 write(*,*) '--INIT_VAL: an error occured in spline.'
      error = .true.
      return      
      end

