# 1 "set_intval_to_zero.F"
c =====================================================================
c
c     SUBROUTINE SET_INTVAL_TO_ZERO
c 
c     PURPOSE: this routine sets all variables that are used for
c                 doing the integrations to zero
c
c     VARIABLES:
c 
c     OUT: Int_Fluxes : two dim array holding the integrated Fluxes of
c                          the different processes during the
c                          different periods
c          Int_Rates  : two dim array holding the integrated Rates of
c                          change of the different processes during
c
c     REVISION:
c
c     date     author  remarks
c   
c     31.07.96   ng    first implementation
c     18.10.99   ng    adapted for interannual variability runs
c
c =====================================================================
c
      subroutine set_intval_to_zero(Int_Fluxes,Int_Rates)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 34 "set_intval_to_zero.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 35 "set_intval_to_zero.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 36 "set_intval_to_zero.F" 2
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      integer ny,i
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      do ny = 1,nyearmax
         do i = 1,9
            int_fluxes(ny,i) = 0.0d0
         enddo
         do i = 1,6
            int_rates(ny,i) = 0.0d0
         enddo
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

