# 1 "set_sums_to_zero.F"
c =====================================================================
c
c     SUBROUTINE SET_SUMS_TO_ZERO
c 
c     PURPOSE: this routine sets all variables that are used for
c                 calculating averages to zero
c
c     VARIABLES:
c 
c     OUT: sum_fract    : sum for calculating average fractionation factor
c          sum_kex      : sum for calculating average kex
c          sum_dCdz     : sum for calculating average vertical dic gradient
c          sum_ddC13dz  : sum for calculating average vertical dC13 gradient
c          sum_dc13_prc : sum for calculating sum of dc13 value of prc
c          nsum_dc13_prc: number of values used in sum_dc13_prc
c 
c     REVISION:
c
c     date     author  remarks
c   
c     31.07.96   ng    first implementation
c     18.10.99   ng    adapted for interannual variability runs
c
c =====================================================================
c
      subroutine set_sums_to_zero(
     $     sum_fract,sum_kex,
     $     sum_dcdz, sum_ddC13dz,
     $     sum_dc13_prc,nsum_dc13_prc)
c
      implicit none
c
c ---------------------------------------------------------------------
c     global variables
c ---------------------------------------------------------------------
c
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 38 "set_sums_to_zero.F" 2
c
c ---------------------------------------------------------------------
c     local variables
c ---------------------------------------------------------------------
c
      integer i
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      sum_fract = 0.0d0
      sum_kex = 0.0d0
      sum_dcdz = 0.0d0
      sum_ddC13dz = 0.0d0
      do i = 1,4
         sum_dc13_prc(i) = 0.d0
         nsum_dc13_prc(i) = 0
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c        
      return
      end

