# 1 "write_mc_fluxanomalies_tofile.F"
c =====================================================================
c
c     SUBROUTINE WRITE_MC_FLUXANOMALIES_TOFILE
c
c     PURPOSE: writes the flux anomalies to a file
c     
c
c     VARIABLES:
c 
c     IN:  unit                : unit number to write to
c          tstart              : start time of integration
c          ts                  : time step
c          nstep               : number of steps
c          nstep2              : number of samples in sg* arrays
c          rsmpl_step          : resampling time step of sg* arrays
c          fluxes_std_runavg   : running avg of fluxes_std
c          mean_fluxes_runavg  : running avg of mean_fluxes
c          sg_fluxes_runavg    : running avg of sg_fluxes
c
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     09.06.02   ng     first implementation, on the basis of write_mc_fluxes
c                                         to_file.F
c 
c =====================================================================
c
      subroutine write_mc_fluxanomalies_tofile(
     $     unit,tstart,ts,nstep,nstep2,rsmpl_step,
     $     fluxes_std_runavg, mean_fluxes_runavg,
     $     sg_fluxes_runavg,error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 43 "write_mc_fluxanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 44 "write_mc_fluxanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 45 "write_mc_fluxanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 46 "write_mc_fluxanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/anomalies.h" 1
c======================= include file averages.h ==============================
c
c variables that store anomalies
c
c REVISIONS:
c
c date     author    remarks
c
c 08.06.00 ng        first implementation
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c 
c D_C_avg         dp a   average Delta C due to the different proc.       muM/kg/ts
c D_C_anom        dp a   anomalies of Delta C                             muM/kg/ts   
c fluxes_avg      dp a   average Flux of DIC due to the different proc.   mol C/m2/s
c fluxes_anom     dp a   anomalies of Delta C                             mol C/m2/s
c D_C_a_runavg    dp a   365 days running anomalies of Delta C            muM/kg/ts   
c fluxes_a_runavg dp a   365 days running anomalies of fluxes             mol C/m2/s 
c
c-------------------------------------------------------------------------
c
      double precision D_C_avg(nproc_rates,nstepmax)
      double precision D_C_anom(nproc_rates,nstepmax)
      double precision fluxes_avg(nproc_fluxes,nstepmax)
      double precision fluxes_anom(nproc_fluxes,nstepmax)
      double precision D_C_a_runavg(nproc_rates,nstepmax)
      double precision fluxes_a_runavg(nproc_fluxes,nstepmax)
# 47 "write_mc_fluxanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_plot_slabs.h" 1
c================== include file mc_plot_slabs.h =========================
c
c variables that contain plot information for monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c
c variables:
c
c name                type   description
c---------------------------------------------------------------------------
c  		      
c nstepmax2           i  s   maximum number of values on time axis
c nstep               i  s   number of resampled values
c rsmpl_step          i  s   every i'th sample is resampled
c mc_D_c              dp a   array of resampled D_C array for mc analysis
c mc_fluxes           dp a   array of resampled fluxes array for mc analysis
c mc_c_sim            dp a   array of resampled c_sim array for mc analysis
c mc_u_var            dp a   array of resampled inverse calc u
c mc_ddc13_dh_var     dp a   array of resampled inverse calc ddC13_dh
c mean_D_c            dp a   mean D_C of mc runs
c mean_fluxes         dp a   mean fluxes of mc runs
c mean_c_sim          dp a   mean c_sim of mc runs
c mean_u_var          dp a   mean u_var
c mean_ddc13_dh_var   dp a   mean ddc13_dh_var
c wmean_D_c           dp a   weighted mean D_C of mc runs
c wmean_fluxes        dp a   weighted mean fluxes of mc runs
c wmean_c_sim         dp a   weighted mean c_sim of mc runs
c wmean_u_var         dp a   weighted mean u_var
c wmean_ddc13_dh_var  dp a   weighted mean ddc13_dh_var
c sg_D_c              dp a   1-sg uncertainty of D_C
c sg_fluxes           dp a   1-sg uncertainty of fluxes
c sg_c_sim            dp a   1-sg uncertainty of c_sim
c sg_u_var            dp a   1-sg uncertainty of u_var
c sg_ddc13_dh_var     dp a   1-sg uncertainty of ddc13_dh_var
c wsg_D_c             dp a   weighted 1-sg uncertainty of D_C
c wsg_fluxes          dp a   weighted 1-sg uncertainty of fluxes
c wsg_c_sim           dp a   weighted 1-sg uncertainty of c_sim
c wsg_u_var           dp a   weighted 1-sg uncertainty of u_var
c wsg_ddc13_dh_var    dp a   weighted 1-sg uncertainty of ddc13_dh_var
c c_sim_std           dp a   array holding c_sim of standard simulation
c fluxes_std          dp a   array holding fluxes of standard simulation
c d_c_std             dp a   array holding d_c of standard simulation
c u_var_std           dp a   array holding inv. calc. u of std simulation
c ddc13_dh_std        dp a   array holding inv. calc. ddc13_dh of std sim.
c
c                                 to the different proc.                mol C/m2/s
c D_C_std_runavg    dp a   one year running standard Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_std_runavg dp a   one year running standard Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
cc 
c===========================================================================
c
      integer nstepmax2,nstep2,rsmpl_step
      parameter(nstepmax2 = 200)
c
      double precision mc_D_c(nrunmax,nproc_rates,nstepmax2)
      double precision mc_fluxes(nrunmax,nproc_fluxes,nstepmax2)
      double precision mc_c_sim(nrunmax,nstepmax2)
      double precision mean_D_c(nproc_rates,nstepmax2)
      double precision mean_fluxes(nproc_fluxes,nstepmax2)
      double precision mean_c_sim(nstepmax2)
      double precision wmean_D_c(nproc_rates,nstepmax2)
      double precision wmean_fluxes(nproc_fluxes,nstepmax2)
      double precision wmean_c_sim(nstepmax2)
      double precision sg_D_c(nproc_rates,nstepmax2)
      double precision sg_fluxes(nproc_fluxes,nstepmax2)
      double precision sg_c_sim(nstepmax2)
      double precision wsg_D_c(nproc_rates,nstepmax2)
      double precision wsg_fluxes(nproc_fluxes,nstepmax2)
      double precision wsg_c_sim(nstepmax2)
      double precision mc_weight(nrunmax)
      double precision c_sim_std(nstepmax)
      double precision d_c_std(nproc_rates,nstepmax)
      double precision fluxes_std(nproc_fluxes,nstepmax)
c
      double precision mc_u_var(nrunmax,nstepmax2)
      double precision mc_ddc13_dh_var(nrunmax,nstepmax2)
      double precision mean_u_var(nstepmax2)
      double precision mean_ddc13_dh_var(nstepmax2)
      double precision wmean_u_var(nstepmax2)
      double precision wmean_ddc13_dh_var(nstepmax2)
      double precision sg_u_var(nstepmax2)
      double precision sg_ddc13_dh_var(nstepmax2)
      double precision wsg_u_var(nstepmax2)
      double precision wsg_ddc13_dh_var(nstepmax2)
      double precision u_var_std(nstepmax)
      double precision ddc13_dh_var_std(nstepmax)
c
      double precision fluxes_std_runavg(nproc_fluxes,nstepmax), 
     $     D_C_std_runavg(nproc_rates,nstepmax)
      double precision mean_d_c_runavg(nproc_rates,nstepmax2),
     $        sg_D_c_runavg(nproc_rates,nstepmax2),       
     $        mean_fluxes_runavg(nproc_fluxes,nstepmax2),
     $        sg_fluxes_runavg(nproc_fluxes,nstepmax2)   

# 48 "write_mc_fluxanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/runavg.h" 1
c======================= include file runavg.h ==============================
c
c variables that store running averages
c
c REVISIONS:
c
c date     author    remarks
c
c 08.06.00 ng        first implementation
c
c variables:
c
c name              type   description
c-----------------------------------------------------------------------------
c 
c D_C_runavg        dp a   one year running avg Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_runavg     dp a   one year running avg Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
c-------------------------------------------------------------------------
c
      double precision D_C_runavg(nproc_rates,nstepmax)
      double precision fluxes_runavg(nproc_fluxes,nstepmax)
# 49 "write_mc_fluxanomalies_tofile.F" 2
c
      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,k2,i
      double precision fluxes_gd(nproc_fluxes)
      double precision fluxes_gd_ub(nproc_fluxes)
      double precision fluxes_gd_lb(nproc_fluxes)
      double precision sec_day,g_mol,day_year
      parameter (sec_day = 24.d0 * 3600.d0, g_mol = 12.01d0)
      parameter (day_year = 365.d0)
      character*27 tmp(nproc_fluxes)
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     statement
c --------------------------------------------------------------------
c     
      write(*,*) '--WRITE_MC_FLUXANOMALIES_TOFILE: saving values...'


      error = .false.
      time = tstart
c
c --------------------------------------------------------------------
c     loop over all simulated values
c --------------------------------------------------------------------
c     
      do k2 = 1,nstep2
c
         k = (k2-1)*rsmpl_step + 1
         
         write(*,*) ' working on step k2,k : ',k2,k
c
c --------------------------------------------------------------------
c     change units of fluxes to mol m-2 day-1
c      calculate also upper and lower boundaries from mc analysis
c --------------------------------------------------------------------
c
         do i = 1,nproc_fluxes
            fluxes_gd(i) = fluxes_std_runavg(i,k) * sec_day * day_year 
            fluxes_gd_ub(i) = (fluxes_std_runavg(i,k) 
     $           + sg_fluxes_runavg(i,k2))
     $           * sec_day * day_year 
            fluxes_gd_lb(i) = (fluxes_std_runavg(i,k) 
     $           - sg_fluxes_runavg(i,k2))
     $           * sec_day * day_year 
         enddo
c
c --------------------------------------------------------------------
c     write to temporary array for output
c --------------------------------------------------------------------
c
         do i = 1,nproc_fluxes-3
            write(tmp(i),'(3(f8.4,1x))') 
     $           fluxes_gd(i),fluxes_gd_lb(i),fluxes_gd_ub(i)
         enddo
c
c         write(*,*) 'values : ',(tmp(i),i=1,nproc_fluxes-3)
c
c --------------------------------------------------------------------
c     write to file
c --------------------------------------------------------------------
c
         write(unit,9000) 
     $        time,
     $        (tmp(i),i=1,nproc_fluxes-3)
c
 9000    format(f9.4,1x,10(a26))
c
c --------------------------------------------------------------------
c     increase time
c --------------------------------------------------------------------
c
         time = time + float(rsmpl_step)*ts
         write(*,*) ' time : ',time
c
c --------------------------------------------------------------------
c     end of loop over all simulated values
c --------------------------------------------------------------------
c
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_MC_FLUXANOMALIES_TOFILE: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











