# 1 "write_mc_fluxes_tofile.F"
c =====================================================================
c
c     SUBROUTINE WRITE_MC_FLUXES_TOFILE
c
c     PURPOSE: writes the rates of change to a file specified by
c                the unit number unit, this special version writes also
c                the means, weighted means, the sigma and weighted sigmas
c                calculated from the monte carlo analysis to the unit 
c     
c
c     VARIABLES:
c 
c     IN:  unit            : unit number to write to
c          tstart          : start time of integration
c          ts              : time step
c          nstep2          : number of samples in sg* arrays
c          rsmpl_step      : resampling time step of sg* arrays
c          fluxes_std      : fluxes of the different processes
c          mean_fluxes     : mean fluxes of mc runs
c          wmean_fluxes    : weighted mean fluxes of mc runs
c          sg_fluxes       : 1-sg uncertainty of fluxes
c          wsg_fluxes      : weighted 1-sg uncertainty of fluxes
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     03.08.96   ng     first implementation
c     18.10.99   ng     adapted for interannual variability
c     22.05.03   bx     added output file mc_fluxes_diff.mc
c 
c =====================================================================
c
      subroutine write_mc_fluxes_tofile(unit,unit2,tstart,ts,
     $     nstep2,rsmpl_step,
     $     fluxes_std,
     $     mean_fluxes,wmean_fluxes,sg_fluxes,wsg_fluxes,
     $     error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 48 "write_mc_fluxes_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/monte_carlo.h" 1
c===================== include file monte_carlo.h =========================
c
c general variables for monte carlo simulations
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c  
c nrunmax       i  s   maximal number of mc runs             
c nrun          i  s   number of mc runs
c
c *_r          dp  s   parameters with a random component added. size of
c                        random component is proportional to sg of this
c                        parameter. For the parameter definitions see
c                        the *_params.h files 
c 
c
c===========================================================================
c
      integer nrunmax,nrun
      parameter(nrunmax = 2000)
      
      double precision gasex_fact_r,D_fco2_corr_r
      double precision diff_fact_r,D_dcdz_r,ddC13_dC_bml_r,lent_const_r
      double precision dlent_dh_r
      double precision D_dc13_org_r
      double precision u_r,dc_dh_r,ddc13_dh_r
c
# 49 "write_mc_fluxes_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 50 "write_mc_fluxes_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 51 "write_mc_fluxes_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_statistics.h" 1
c================== include file mc_statistics.h =========================
c
c variables of statistics of monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c  
c int_rates_std   dp a   array holding standard integrated rates
c int_fluxes_std  dp a   array holding standard integrated fluxes
c costfn_std      dp s   value of cost function for standard run
c rsq_std         dp s   r**2 value for standard run
c chisq_std       dp s   chi**2 value for standard run
c amplitude_std   dp s   amplitude of standard run
c c_min_std       dp s   minimum C of standard run
c c_max_std       dp s   maximum C of standard run
c
c var_int_rates   dp a   array holding variance of integrated rates 
c                            (over monte carlo runs)
c var_int_fluxes  dp a   array holding variance of integrated fluxes
c wvar_int_rates  dp a   array holding weighted variance of integrated rates 
c                                 (over monte carlo runs)
c wvar_int_fluxes dp a   array holding weighted variance of integrated fluxes
c sum_costfn      dp s   sum of cost function
c mean_costfn     dp s   mean of cost function
c costfn_min      dp s   minimum of cost function
c costfn_max      dp s   maximum of cost function
c 
c sg_int_rates    dp s   1-sigma uncertainty of int_rates
c sg_int_fluxes   dp s   1-sigma uncertainty of int_fluxes
c wsg_int_rates   dp s   1-sigma weighted uncertainty of int_rates
c wsg_int_fluxes  dp s   1-sigma weighted uncertainty of int_fluxes
c 
c===========================================================================
c
      double precision int_rates_std(nyearmax,nproc_rates)
      double precision int_fluxes_std(nyearmax,nproc_fluxes)
      double precision costfn_std
      double precision closure_std,rsq_std,chisq_std,amplitude_std
      double precision c_min_std,c_max_std
c
      double precision var_int_rates(nyearmax,nproc_rates)
      double precision var_int_fluxes(nyearmax,nproc_fluxes)
      double precision wvar_int_rates(nyearmax,nproc_rates)
      double precision wvar_int_fluxes(nyearmax,nproc_fluxes)
c   
      double precision sg_int_rates(nyearmax,nproc_rates)
      double precision sg_int_fluxes(nyearmax,nproc_fluxes)
      double precision wsg_int_rates(nyearmax,nproc_rates)
      double precision wsg_int_fluxes(nyearmax,nproc_fluxes)
c
      double precision sum_costfn,mean_costfn
      double precision costfn_min,costfn_max
c

# 52 "write_mc_fluxes_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 53 "write_mc_fluxes_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/mc_plot_slabs.h" 1
c================== include file mc_plot_slabs.h =========================
c
c variables that contain plot information for monte carlo runs
c
c REVISIONS:
c
c date     author    remarks
c
c 19.8.96  ng        first implementation
c
c variables:
c
c name                type   description
c---------------------------------------------------------------------------
c  		      
c nstepmax2           i  s   maximum number of values on time axis
c nstep               i  s   number of resampled values
c rsmpl_step          i  s   every i'th sample is resampled
c mc_D_c              dp a   array of resampled D_C array for mc analysis
c mc_fluxes           dp a   array of resampled fluxes array for mc analysis
c mc_c_sim            dp a   array of resampled c_sim array for mc analysis
c mc_u_var            dp a   array of resampled inverse calc u
c mc_ddc13_dh_var     dp a   array of resampled inverse calc ddC13_dh
c mean_D_c            dp a   mean D_C of mc runs
c mean_fluxes         dp a   mean fluxes of mc runs
c mean_c_sim          dp a   mean c_sim of mc runs
c mean_u_var          dp a   mean u_var
c mean_ddc13_dh_var   dp a   mean ddc13_dh_var
c wmean_D_c           dp a   weighted mean D_C of mc runs
c wmean_fluxes        dp a   weighted mean fluxes of mc runs
c wmean_c_sim         dp a   weighted mean c_sim of mc runs
c wmean_u_var         dp a   weighted mean u_var
c wmean_ddc13_dh_var  dp a   weighted mean ddc13_dh_var
c sg_D_c              dp a   1-sg uncertainty of D_C
c sg_fluxes           dp a   1-sg uncertainty of fluxes
c sg_c_sim            dp a   1-sg uncertainty of c_sim
c sg_u_var            dp a   1-sg uncertainty of u_var
c sg_ddc13_dh_var     dp a   1-sg uncertainty of ddc13_dh_var
c wsg_D_c             dp a   weighted 1-sg uncertainty of D_C
c wsg_fluxes          dp a   weighted 1-sg uncertainty of fluxes
c wsg_c_sim           dp a   weighted 1-sg uncertainty of c_sim
c wsg_u_var           dp a   weighted 1-sg uncertainty of u_var
c wsg_ddc13_dh_var    dp a   weighted 1-sg uncertainty of ddc13_dh_var
c c_sim_std           dp a   array holding c_sim of standard simulation
c fluxes_std          dp a   array holding fluxes of standard simulation
c d_c_std             dp a   array holding d_c of standard simulation
c u_var_std           dp a   array holding inv. calc. u of std simulation
c ddc13_dh_std        dp a   array holding inv. calc. ddc13_dh of std sim.
c
c                                 to the different proc.                mol C/m2/s
c D_C_std_runavg    dp a   one year running standard Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_std_runavg dp a   one year running standard Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
cc 
c===========================================================================
c
      integer nstepmax2,nstep2,rsmpl_step
      parameter(nstepmax2 = 200)
c
      double precision mc_D_c(nrunmax,nproc_rates,nstepmax2)
      double precision mc_fluxes(nrunmax,nproc_fluxes,nstepmax2)
      double precision mc_c_sim(nrunmax,nstepmax2)
      double precision mean_D_c(nproc_rates,nstepmax2)
      double precision mean_fluxes(nproc_fluxes,nstepmax2)
      double precision mean_c_sim(nstepmax2)
      double precision wmean_D_c(nproc_rates,nstepmax2)
      double precision wmean_fluxes(nproc_fluxes,nstepmax2)
      double precision wmean_c_sim(nstepmax2)
      double precision sg_D_c(nproc_rates,nstepmax2)
      double precision sg_fluxes(nproc_fluxes,nstepmax2)
      double precision sg_c_sim(nstepmax2)
      double precision wsg_D_c(nproc_rates,nstepmax2)
      double precision wsg_fluxes(nproc_fluxes,nstepmax2)
      double precision wsg_c_sim(nstepmax2)
      double precision mc_weight(nrunmax)
      double precision c_sim_std(nstepmax)
      double precision d_c_std(nproc_rates,nstepmax)
      double precision fluxes_std(nproc_fluxes,nstepmax)
c
      double precision mc_u_var(nrunmax,nstepmax2)
      double precision mc_ddc13_dh_var(nrunmax,nstepmax2)
      double precision mean_u_var(nstepmax2)
      double precision mean_ddc13_dh_var(nstepmax2)
      double precision wmean_u_var(nstepmax2)
      double precision wmean_ddc13_dh_var(nstepmax2)
      double precision sg_u_var(nstepmax2)
      double precision sg_ddc13_dh_var(nstepmax2)
      double precision wsg_u_var(nstepmax2)
      double precision wsg_ddc13_dh_var(nstepmax2)
      double precision u_var_std(nstepmax)
      double precision ddc13_dh_var_std(nstepmax)
c
      double precision fluxes_std_runavg(nproc_fluxes,nstepmax), 
     $     D_C_std_runavg(nproc_rates,nstepmax)
      double precision mean_d_c_runavg(nproc_rates,nstepmax2),
     $        sg_D_c_runavg(nproc_rates,nstepmax2),       
     $        mean_fluxes_runavg(nproc_fluxes,nstepmax2),
     $        sg_fluxes_runavg(nproc_fluxes,nstepmax2)   

# 54 "write_mc_fluxes_tofile.F" 2
c
      logical error
      integer unit
cBX-a
      integer unit2
cBX-e
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,k2,i
      double precision fluxes_gd(nproc_fluxes)
      double precision fluxes_gd_ub(nproc_fluxes)
      double precision fluxes_gd_lb(nproc_fluxes)
      double precision sec_day,g_mol,day_year
      parameter (sec_day = 24.d0 * 3600.d0, g_mol = 12.01d0)
      parameter (day_year = 365.)
cBX      character*27 tmp(nproc_fluxes)
      character*33 tmp(nproc_fluxes)
cBX-a
      character*30 filename
      character*22 tmp2(nproc_fluxes)
cBX-e
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      error = .false.
      time = tstart
c
c --------------------------------------------------------------------
c     loop over all simulated values
c --------------------------------------------------------------------
c     
      do k2 = 1,nstep2
c
         k = (k2-1)*rsmpl_step + 1
c
c --------------------------------------------------------------------
c     change units of fluxes to mol m-2 day-1
c      calculate also upper and lower boundaries from mc analysis
c --------------------------------------------------------------------
c
         do i = 1,nproc_fluxes
            fluxes_gd(i) = fluxes_std(i,k) * sec_day * day_year 
            fluxes_gd_ub(i) = (fluxes_std(i,k) + wsg_fluxes(i,k2))
     $           * sec_day * day_year 
            fluxes_gd_lb(i) = (fluxes_std(i,k) - wsg_fluxes(i,k2))
     $           * sec_day * day_year 
         enddo
c
c --------------------------------------------------------------------
c     write to temporary array for output
c --------------------------------------------------------------------
c
         do i = 1,nproc_fluxes-3
cBX            write(tmp(i),'(3(f8.4,1x))') 
            write(tmp(i),'(3(f10.4,1x))') 
     $           fluxes_gd(i),fluxes_gd_lb(i),fluxes_gd_ub(i)
cBX-a
            write(tmp2(i),'(2(f10.4,1x))') 
     $           fluxes_gd(i),wsg_fluxes(i,k2)*sec_day*day_year
cBX-e
         enddo
c
c --------------------------------------------------------------------
c     write to file
c --------------------------------------------------------------------
c
         write(unit,9000) 
     $        time,
     $        (tmp(i),i=1,nproc_fluxes-3)
c
cBX 9000    format(f9.4,1x,10(a26))
 9000    format(f9.4,1x,10(a33))
cBX-a
c
c --------------------------------------------------------------------
c     write to 2nd unit for 2nd file
c --------------------------------------------------------------------
c
         write(unit2,9001) 
     $        time,
     $        (tmp2(i),i=1,nproc_fluxes-3)
c
 9001    format(f9.4,1x,10(a22))
c
c --------------------------------------------------------------------
c     increase time
c --------------------------------------------------------------------
c
         time = time + float(rsmpl_step)*ts
c
c --------------------------------------------------------------------
c     end of loop over all simulated values
c --------------------------------------------------------------------
c
c
      enddo
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_FLUXES_TOFILE: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











