# 1 "write_rateanomalies_tofile.F"
c =====================================================================
c
c     SUBROUTINE WRITE_RATEANOMALIES_TOFILE
c
c     PURPOSE: writes the flux anomalies to a file
c     
c
c     VARIABLES:
c 
c     IN:  unit            : unit number to write to
c          tstart          : start time of integration
c          ts              : time step
c          nstep           : number of steps
c          D_C_avg         : average timeseries of dC/dt
c          D_C_anom        : anomaly timeseries of dC/dt
c          D_C_runavg      : running average timeseries of dC/dt
c
c
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     08.06.00   ng     first implementation
c     29.08.01   ng     added running averge
c 
c =====================================================================
c
      subroutine write_rateanomalies_tofile(unit,tstart,ts,nstep,
     $        D_C_avg,D_C_anom,D_C_runavg,
     $        error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 41 "write_rateanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 42 "write_rateanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 43 "write_rateanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/anomalies.h" 1
c======================= include file averages.h ==============================
c
c variables that store anomalies
c
c REVISIONS:
c
c date     author    remarks
c
c 08.06.00 ng        first implementation
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c 
c D_C_avg         dp a   average Delta C due to the different proc.       muM/kg/ts
c D_C_anom        dp a   anomalies of Delta C                             muM/kg/ts   
c fluxes_avg      dp a   average Flux of DIC due to the different proc.   mol C/m2/s
c fluxes_anom     dp a   anomalies of Delta C                             mol C/m2/s
c D_C_a_runavg    dp a   365 days running anomalies of Delta C            muM/kg/ts   
c fluxes_a_runavg dp a   365 days running anomalies of fluxes             mol C/m2/s 
c
c-------------------------------------------------------------------------
c
      double precision D_C_avg(nproc_rates,nstepmax)
      double precision D_C_anom(nproc_rates,nstepmax)
      double precision fluxes_avg(nproc_fluxes,nstepmax)
      double precision fluxes_anom(nproc_fluxes,nstepmax)
      double precision D_C_a_runavg(nproc_rates,nstepmax)
      double precision fluxes_a_runavg(nproc_fluxes,nstepmax)
# 44 "write_rateanomalies_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/runavg.h" 1
c======================= include file runavg.h ==============================
c
c variables that store running averages
c
c REVISIONS:
c
c date     author    remarks
c
c 08.06.00 ng        first implementation
c
c variables:
c
c name              type   description
c-----------------------------------------------------------------------------
c 
c D_C_runavg        dp a   one year running avg Delta C due to the 
c                                 different proc.                       muM/kg/ts
c fluxes_runavg     dp a   one year running avg Flux of DIC due 
c                                 to the different proc.                mol C/m2/s
c-------------------------------------------------------------------------
c
      double precision D_C_runavg(nproc_rates,nstepmax)
      double precision fluxes_runavg(nproc_fluxes,nstepmax)
# 45 "write_rateanomalies_tofile.F" 2
c
      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,i
      double precision dcdt_avg(nproc_rates)
      double precision dcdt_anom(nproc_rates)
      double precision dcdt_runavg(nproc_rates)
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      error = .false.
      time = tstart
c
c --------------------------------------------------------------------
c     loop over all simulated values
c --------------------------------------------------------------------
c     
      do k = 1,nstep
c
c --------------------------------------------------------------------
c     change units of D_C (now it is umol kg-1) to umol kg-1 yr-1
c --------------------------------------------------------------------
c
         do i = 1,nproc_rates
            dcdt_avg(i) = d_C_avg(i,k) / ts
            dcdt_anom(i) = d_C_anom(i,k) / ts
            dcdt_runavg(i) = d_C_runavg(i,k) / ts
         enddo
c
c --------------------------------------------------------------------
c     write to file
c --------------------------------------------------------------------
c
         write(unit,9000) 
     $        time,
     $        (dcdt_avg(i),i=1,nproc_rates),
     $        (dcdt_anom(i),i=1,nproc_rates),
     $        (dcdt_runavg(i),i=1,nproc_rates)
c
 9000    format(f8.3,1x,21(f8.3,1x))
c
c --------------------------------------------------------------------
c     increase time
c --------------------------------------------------------------------
c
         time = time + ts
c
c --------------------------------------------------------------------
c     end of loop over all simulated values
c --------------------------------------------------------------------
c
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_RATEANOMALIES_TOFILE: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











