# 1 "write_rates_tofile.F"
c =====================================================================
c
c     SUBROUTINE WRITE_RATES_TOFILE
c
c     PURPOSE: writes the rates of change to a file specified by
c                the unit number unit
c     
c
c     VARIABLES:
c 
c     IN:  unit            : unit number to write to
c          tstart          : start time of integration
c          ts              : time step
c          nstep           : number of steps
c          D_C             : array holding the rates of change
c          c_obs           : array holding the observed seasonal cycle of C
c          c_sim           : array holding the simulated seasonal cycle of C
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     03.08.96   ng     first implementation
c      5.08.96   ng     included c_obs and c_sim
c 
c =====================================================================
c
      subroutine write_rates_tofile(unit,tstart,ts,nstep,
     $        D_c,c_obs,c_sim,error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 39 "write_rates_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 40 "write_rates_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 41 "write_rates_tofile.F" 2
c
      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,i
      double precision dcdt(nproc_rates)
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      error = .false.
      time = tstart
c
c --------------------------------------------------------------------
c     loop over all simulated values
c --------------------------------------------------------------------
c     
      do k = 1,nstep
c
c --------------------------------------------------------------------
c     change units of D_C (now it is umol kg-1) to umol kg-1 yr-1
c --------------------------------------------------------------------
c
         do i = 1,nproc_rates
            dcdt(i) = d_C(i,k) / ts
         enddo
c
c --------------------------------------------------------------------
c     write to file
c --------------------------------------------------------------------
c
         write(unit,9000) 
     $        time,
     $        (dcdt(i),i=1,nproc_rates),
     $        c_sim(k),c_obs(k)
c
 9000    format(f8.3,1x,7(f8.3,1x),2(f7.2,1x))
c
c --------------------------------------------------------------------
c     increase time
c --------------------------------------------------------------------
c
         time = time + ts
c
c --------------------------------------------------------------------
c     end of loop over all simulated values
c --------------------------------------------------------------------
c
c
      enddo
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_RATES_TOFILE: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











