# 1 "write_solution_tofile.F"
c =====================================================================
c
c     SUBROUTINE WRITE_SOLUTION_TOFILE
c
c     PURPOSE: writes all other solutions to the model to a file
c     
c
c     VARIABLES:
c 
c     IN:  unit            : unit number to write to
c          tstart          : start time of integration
c          ts              : time step
c          nstep           : number of steps
c          sol_scheme      : solution scheme
c          u_var           : computed u 
c
c     OUT: error           : logical indicating that an error occured
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     19.10.99   ng     first implementation
c 
c =====================================================================
c
      subroutine write_solution_tofile(unit,tstart,ts,nstep,
     $        sol_scheme,u_var,error)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 36 "write_solution_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 37 "write_solution_tofile.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/solution.h" 1
c================== include file solution.h =========================
c
c variables for sensitivity analysis
c
c REVISIONS:
c
c date     author    remarks
c
c 21.8.96  ng        first implementation
c 18.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name            type   description
c---------------------------------------------------------------------------
c 
c u_var           dp a   inverse calculated horizontal velocity m s-1
c 
c===========================================================================
c
      double precision u_var(nstepmax)
# 38 "write_solution_tofile.F" 2
c
      logical error
      integer unit
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c     
      integer k,i
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
      error = .false.
      time = tstart
c
c --------------------------------------------------------------------
c     loop over all simulated values
c --------------------------------------------------------------------
c     
      do k = 1,nstep
c
c --------------------------------------------------------------------
c     write to file
c --------------------------------------------------------------------
c
         write(unit,9000,err=9900) 
     $        time,
     $        u_var(k)
c
cBX 9000    format(f6.1,1x,f8.4)
 9000    format(f8.3,1x,f8.4)
c
c --------------------------------------------------------------------
c     increase time
c --------------------------------------------------------------------
c
         time = time + ts
c
c --------------------------------------------------------------------
c     end of loop over all simulated values
c --------------------------------------------------------------------
c
      enddo
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return
c
c --------------------------------------------------------------------
c     error handling
c --------------------------------------------------------------------
c     
 9900 write(unit,*) '--WRITE_SOLUTION_TOFILE: ',
     $     'an error occurred while writing...'
      error = .true.
c
      return

      end











