c===================== include file harm_coeff.h =========================
c
c coefficients of the harmonic fits to the input data
c
c REVISIONS:
c
c date     author    remarks
c
c 30.7.96  ng        first fits (not yet checked)
c                      for wind-speed : still using old fits
c 10.9.96  ng        updated coefficients, using only coeff which
c                      are significant at the 5% level (tested by
c                      Student t-test)
c                    changes include temperature,ddic_dz and dc13_atm
c 17.10.99 ng        adapted for interannual variability runs at BERM
c 06.06.00 ng        added new coefficients based on combined BERM/BATS
c                      data set
c 24.08.01 ng        added new coefficients for 1983-2001 (BERM/BATS)
c 03.10.01 bx        added new coefficients for HAWI_harm
c 16.10.01 bx        added new coefficients for HAWI_hali
c 03.05.02 ng        added new coefficients for 1983 to 2002 (BERM/BATS)
c 10.01.03 bx        changed coefficients for HAWI_hali to detrended
c                      values for c_pco2a and later in following list
c 13.05.03 bx        added new coefficients for HAWI_CDRGatm
c
c variables:
c
c name        type   description
c-------------------------------------------------------------------------
c
c c_temp      dp  a   coefficients for mixed layer temperature    [deg C]
c c_sal       dp  a   coefficients for mixed layer salinity       [psu]
c c_sdic      dp  a   coefficients for mixed layer normalized C   [umol/kg]
c c_salk      dp  a   coefficients for mixed layer normalized Alk [umol/kg]
c c_dc13      dp  a   coefficients for mixed layer dC13           [permil]
c c_fco2_o    dp  a   coefficients for mixed layer fCO2           [ppm]
c c_pco2a     dp  a   coefficients for atm pCO2                   [ppm]
c c_dc13a     dp  a   coefficients for atm dC13                   [per mil]
c c_ws        dp  a   coefficients for wind wind speed            [m s-1]
c                          fit                                    [m2 s-2]
c c_h         dp  a   coefficients for mld                        [m]
c c_dCdz      dp  a   coefficients for dC/dz                      [umol/kg m]
c c_kz_var    dp  a   coefficients for seasonally varying kz      [m2 s-1]
c
c===========================================================================
c
      double precision c_temp(7),c_sal(7)
      double precision c_sdic(7),c_salk(7)
      double precision c_dc13(7),c_fco2_o(7)
      double precision c_pco2a(7),c_dc13a(7)
      double precision c_h(7)
      double precision c_dCdz(7)
      double precision c_kz_var(7),c_ws(7)

#ifdef BATS_89_93
c
c     
c --------------------------------------------------------------------
c     BATS specific coefficients (1989-1993)
c --------------------------------------------------------------------
c
      data c_temp    / 0.23506d+2,  
     $                -0.3197d+1,-0.2429d+1, 0.5994d+0, 0.4677d+0,
     $                 0.0d+0,0.0d+0/
c
      data c_sal     / 0.36586d+2,
     $                 0.8454d-1,0.2748d-1,0.0d0,0.0d0,
     $                 0.0d+0,0.0d+0/
c
      data c_sdic   / 0.20421d4,
     $                 0.1556d+2, 0.9945d+0, 0.5501d+0, 0.2533d+0,
     $                 0.0d+0,0.0d+0/
c
      data c_dc13   / 0.13496d+1,
     $                -0.1025d+0,0.59113d-2,-0.19802d-1,-0.11080d-1,
     $                 0.0d+0,0.0d+0/
c
      data c_salk   / 0.2392d+4,
     $                 0.0d+0,0.0d+0,0.0d+0,0.0d+0,
     $                 0.0d+0,0.0d+0/
c
      data c_fco2_o  / 0.34644d+3,
     $                -0.2056d+2,-0.2703d+2, 0.8252d+1, 0.6674d+1,
     $                 0.0d+0,0.0d+0/
c
      data c_pco2a  / 0.35689d+3,
     $                0.4351d+1, 0.1126d+1,-0.2002d+1, 0.7626d+0,
     $                0.3959d+0,-0.3621d+0/
c
      data c_dc13a  /-0.78753d+1,
     $                -0.2384d+0, -0.7775d-1, 0.1085d+0,-0.3815d-1,
     $                 0.0d0,0.0d0/
c
      data c_kz_var  / 0.3624d-4 , 
     $                 0.4306d-4 , 0.8956d-5 ,0.5444d-5, -0.1909d-4,
     $                -0.7567d-5,  0.8822d-6/
c
       data c_dCdz    /0.50410d+0,
     $               -0.1578d+0, 0.1728d+0, 0.0d+0,0.0d+0,
     $                0.0d+0,0.0d+0/
#elif BERM_BATS_83_98
c     
c --------------------------------------------------------------------
c     Station 'S' and BATS combined coefficients (1983-1998)
c --------------------------------------------------------------------

      data c_temp    /0.23213d+2,
     $               -0.3438d+1,-0.2158d+1, 0.6349d+0, 0.2140d+0,
     $               -0.1516d+0,-0.1382d+0/
c
      data c_sal     /0.36565d+2,
     $                0.8409d-1, 0.5096d-1,-0.1457d-1, 0.8162d-2,
     $               -0.1859d-1, 0.2561d-1/
c
      data c_sdic    /0.19518d+4,  !@salinity 35
     $                0.1469d+2, 0.3186d+0, 0.1453d+1, 0.6547d+0,
     $                0.1597d+0,-0.9035d+0/
c
      data c_dc13    /0.14155d+1,
     $               -0.9249d-1,-0.1181d-2,-0.2559d-1,-0.5344d-2,
     $                0.3496d-2, 0.3655d-2/
c
      data c_salk    /0.22858d+4,  !@salinity 35
     $               -0.3945d-1, 0.6558d+0, 0.4173d+0,-0.1268d+0,
     $               -0.1957d+0, 0.1699d+0/
c
      data c_fco2_o / 0.33319d+3,
     $               -0.2319d+2,-0.3041d+2, 0.9512d+1, 0.5077d+1,
     $               -0.2230d+1,-0.3026d+1/
c
      data c_pco2a  / 0.35689d+3,  ! same as BATS
     $                 0.4351d+1, 0.1126d+1,-0.2002d+1, 0.7626d+0,
     $                 0.3959d+0,-0.3621d+0/
c
      data c_dc13a  /-0.78753d+1, ! same as BATS
     $                -0.2384d+0, -0.7775d-1, 0.1085d+0,-0.3815d-1,
     $                 0.0d0,0.0d0/
c
      data c_kz_var  / 0.3624d-4 , ! same as BATS
     $                 0.4306d-4 , 0.8956d-5 ,0.5444d-5, -0.1909d-4,
     $                -0.7567d-5,  0.8822d-6/
c
      data c_dCdz    /0.50410d+0, ! same as BATS
     $               -0.1578d+0, 0.1728d+0, 0.0d+0,0.0d+0,
     $                0.0d+0,0.0d+0/
#elif HAWI_harm
c     
c --------------------------------------------------------------------
c     Hawaii station data (1988-2000) - harmonic analysis
c       updated for 2001 data on 07MAY02 BX
c --------------------------------------------------------------------

      data c_temp    / 0.24766d+2,
     $                -0.14477d+1,-0.59380d+0,-0.14058d+0,-0.13480d+0,
     $                 0.32992d-1,-0.81449d-1/
c
      data c_sal     / 0.35016d+2,
     $                -0.21029d-1, 0.46920d-1,-0.11727d-1,-0.25097d-1,
     $                -0.11122d-1,-0.20829d-2/
c
      data c_sdic    / 0.19710d+4,  !@salinity 35
     $                 0.71978d+1, 0.55489d-1, 0.10797d+1, 0.11098d+1,
     $                -0.21853d+0, 0.65690d+0/
c
      data c_dc13    / 0.14114d+1,
     $                -0.47789d-1,-0.36488d-2,-0.52451d-2, 0.13009d-3,
     $                -0.43315d-2, 0.55824d-2/
c
      data c_salk    / 0.23029d+4,  !@salinity 35
     $                 0.80270d-1,-0.10269d+1, 0.49866d+0, 0.16775d+0,
     $                 0.63329d+0, 0.54021d+0/
c
      data c_fco2_o /  0.33738d+3,  !from hawi analysis as a start - not relevant
c                                              if fco2 is calculated online!!!! no update!
     $                -0.10698d+2,-0.65963d+1,-0.10794d+1,-0.13831d+1,
     $                -0.17313d+1,-0.56739d+0/
c
      data c_pco2a  /  0.35190d+3,  ! values from Cape Kumakahi - CMDL monthly mean
c                                              data until DEC2001
     $                 0.37172d+1, 0.35364d+0,-0.11411d+1, 0.71184d+0,
     $                -0.17255d+0,-0.88749d-1/
c
      data c_dc13a  / -0.79562d+1, ! values from Cape Kumakahi - CMDL monthly mean
c                                              data from JAN1990 to DEC2000
     $                -0.19489d+0,-0.10785d-1, 0.59947d-1,-0.31713d-1,
     $                -0.77380d-3, 0.65991d-2/
c
      data c_kz_var  / 0.12541d-6, ! from mld analysis - ctd data until 2001 with stdev
cBX                                              data from JAN1990 to DEC2000 - no update as
cBX                                              of 10JAN03!!!!
     $                 0.10360d-4, 0.15823d-5, 0.19354d-5,-0.52239d-5,
     $                -0.12416d-5, 0.65915d-6/
c
cBX     updated 03JUN02 for data from CTD-MLD
      data c_dCdz    / 0.63179d+0, ! calculated from HOT data set
     $                -0.18015d+0, 0.13057d+0, 0.14912d-1, 0.93730d-1,
     $                -0.49050d-1,-0.12741d-1/
#elif HAWI_hali
c     
c --------------------------------------------------------------------
c     Hawaii station data (1988-2001) - without linear trend
c       updated for 2001 data on 25APR02 BX
c --------------------------------------------------------------------

      data c_temp    / 0.24769d+2,
     $                -0.14445d+1,-0.59389d+0,-0.13827d+0,-0.13657d+0,
     $                 0.31424d-1,-0.82967d-1/
c
      data c_sal     / 0.35007d+2,
     $                -0.29194d-1, 0.47461d-1,-0.16202d-1,-0.24177d-1,
     $                -0.66204d-2, 0.36074d-2/
c
      data c_sdic    / 0.19702d+4,  !@salinity 35
     $                 0.65994d+1, 0.28248d+0, 0.65067d+0, 0.94398d+0,
     $                 0.46003d-2, 0.10497d+1/
c
      data c_dc13    / 0.14302d+1,
     $                -0.35323d-1,-0.67526d-2,-0.19794d-2,-0.35390d-2,
     $                -0.37286d-2,-0.86891d-2/
c
      data c_salk    / 0.23032d+4,  !@salinity 35
     $                 0.13368d+0,-0.87333d+0, 0.49784d+0, 0.35834d+0,
     $                 0.56086d+0, 0.46014d+0/
c
      data c_fco2_o /  0.33502d+3,  !from hawi analysis as a start - not relevant
c                                              if fco2 is calculated online!!!! no update!
     $                -0.11403d+2,-0.67576d+1,-0.13061d+1,-0.23050d+1,
     $                -0.13238d+1, 0.36076d+0/
c
      data c_pco2a  /  0.35186d+3,  ! pCO2 values from Cape Kumakahi - CMDL monthly mean
c                                              data until DEC2001 - update 10JAN03
c                                              unfortunately the wrong data (pco2 iso xco2)
     $                 0.42023d+1, 0.35496d+0,-0.89050d+0, 0.71105d+0,
     $                 0.51808d-2,-0.88914d-1/
c
      data c_dc13a  / -0.79555d+1, ! values from Cape Kumakahi - CMDL monthly mean
c                                              data from JAN1990 to DEC2000 - update 10JAN03
     $                -0.20279d+0,-0.10852d-1, 0.55882d-1,-0.31670d-1,
     $                -0.36720d-2, 0.65989d-2/
c
      data c_kz_var  / 0.17543d-4, ! from mld analysis - ctd data until 2001 with stdev
c                                              data from NOV1988 to DEC2001 - update 10JAN03
     $                 0.10960d-4, 0.20921d-5, 0.24164d-5,-0.50949d-5,
     $                -0.11143d-5, 0.64844d-6/
c
cBX     updated 10JAN03 for data from CTD-MLD - data from 1989 until 1999
      data c_dCdz    / 0.64473d+0, ! calculated from HOT data set
     $                -0.18951d+0, 0.12957d+0, 0.60458d-2, 0.94335d-1,
     $                -0.52134d-1,-0.17519d-1/
#elif HAWI_CDRGatm
c     
c --------------------------------------------------------------------
c     Hawaii station data (1988-2001) - without linear trend
c       updated with data for pCO2a and c13a from CDRG on 13MAY03
c       and for 2002 CDRG ocean data on 21MAY03 BX
c --------------------------------------------------------------------

      data c_temp    / 0.24812d+2,
     $                -0.14119d+1,-0.57805d+0,-0.10165d+0,-0.88825d-1,
     $                 0.67235d-1,-0.10919d+0/
c
      data c_sal     / 0.35024d+2,
     $                -0.31043d-1, 0.41717d-1,-0.81345d-2,-0.26381d-1,
     $                -0.58158d-3,-0.55224d-2/
c
      data c_sdic    / 0.19703d+4,  !@salinity 35
     $                 0.68715d+1, 0.36846d+0, 0.45182d+0, 0.73481d+0,
     $                -0.22355E+0, 0.82337d+0/
c
#ifdef dc13twoharm
      data c_dc13    / 0.14013d+1,
     $                -0.34983d-1,-0.95196d-2,-0.12653d-2,-0.43141d-2,
     $                0.,0./
c
#else
      data c_dc13    / 0.14013d+1,
     $                -0.34983d-1,-0.95196d-2,-0.12653d-2,-0.43141d-2,
     $                -0.52941d-2,-0.85351d-2/
c
#endif
      data c_salk    / 0.23023d+4,  !@salinity 35
     $                 0.33544d+0,-0.19139d+0,-0.10066d+0,-0.76999d-1,
     $                 0.20537E+0, 0.47237d+0/
c
      data c_fco2_o /  0.33502d+3,  !from hawi analysis as a start - not relevant
c                                              if fco2 is calculated online!!!! no update!
     $                -0.11403d+2,-0.67576d+1,-0.13061d+1,-0.23050d+1,
     $                -0.13238d+1, 0.36076d+0/
c
      data c_pco2a  /  0.36092d+3,  ! xCO2 values from Cape Kumakahi - CDRG monthly mean
c$$$c                                              data until DEC2001 - update 13MAY03
     $                 0.36140d+1,-0.16714d+0,-0.93759d+0, 0.69224d+0,
     $                 0.71550d-1,-0.12653d+0/
c
      data c_dc13a  / -0.79609d+1, ! values from Cape Kumakahi - CDRG monthly mean
c                                              data unitl DEC2001 - update 13MAY03
     $                -0.18599d+0, 0.24384d-2, 0.55990d-1,-0.26230d-1,
     $                -0.71237d-2, 0.74483d-2/
c
      data c_kz_var  / 0.17543d-4, ! from mld analysis - ctd data until 2001 with stdev
c                                              data from NOV1988 to DEC2001 - update 10JAN03
     $                 0.10960d-4, 0.20921d-5, 0.24164d-5,-0.50949d-5,
     $                -0.11143d-5, 0.64844d-6/
c
cBX     updated 10JAN03 for data from CTD-MLD - data from 1989 until 1999
      data c_dCdz    / 0.64473d+0, ! calculated from HOT data set
     $                -0.18951d+0, 0.12957d+0, 0.60458d-2, 0.94335d-1,
     $                -0.52134d-1,-0.17519d-1/
#else
c     
c --------------------------------------------------------------------
c     Station 'S' and BATS combined coefficients (1983-2001)
c       updated May 03, 2002
c --------------------------------------------------------------------

      data c_temp    /0.23231d+2,
     $               -0.3491d+1,-0.2171d+1, 0.6304d+0, 0.2167d+0,
     $               -0.2627d-1,-0.8370d-1/
c
      data c_sal     /0.36557d+2,
     $                0.9186d-1, 0.3998d-1,-0.1776d-1, 0.9852d-2,
     $               -0.6274d-2, 0.2737d-1/
c
      data c_sdic    /0.19523d+4,  !@salinity 35
     $                0.1437d+2, 0.1247d+1, 0.9282d+0, 0.6024d+0,
     $               -0.2430d+0,-0.5423d+0/
c
      data c_dc13    /0.13848d+1,
     $               -0.8406d-1,-0.7534d-3,-0.1856d-1,-0.1059d-2,
     $               -0.1306d-2, 0.2271d-2/
c
      data c_salk    /0.22852d+4,  !@salinity 35
     $               -0.3019d+0, 0.7049d+0, -0.2551d-1,-0.3557d+0,
     $               -0.1768d-1, 0.4185d+0/
c
      data c_fco2_o / 0.33422d+3,
     $               -0.2340d+2,-0.2835d+2, 0.1045d+2, 0.4631d+1,
     $               -0.1253d+1,-0.2027d+1/
c
      data c_pco2a  / 0.35645d+3,  ! new coeff May 03, 2002
     $                 0.4073d+1, 0.1252d+1, -0.1315d+1, 0.4781d+0,
     $                -0.2101d-1,-0.3498d+0/
c
      data c_dc13a  /-0.78625+1, ! new coeff May 03, 2002
     $                -0.2239d+0, -0.9744d-1, 0.6619d-1,-0.1664d-1,
     $                 0.6341d-2,  0.1724d-1/
c
      data c_kz_var  / 0.3624d-4 , ! same as BATS, not updated
     $                 0.4306d-4 , 0.8956d-5 ,0.5444d-5, -0.1909d-4,
     $                -0.7567d-5,  0.8822d-6/

      data c_dCdz    /0.6661d+0, ! BATS 1988 - 2001; stations 1-156
     $               -0.1969d+0, 0.2734d+0, 0.2231d-1, 0.4882d-1,
     $               -0.6619d-2,-0.2185d-1/


#endif
c
      
c     
c --------------------------------------------------------------------
c     unspecific coefficients or user able to choose interactively
c --------------------------------------------------------------------
c
#ifdef BATS_89_93
c Isemer and Hasse coefficients
c
      data c_ws   /   7.173d+0 , 
     $                0.764d+0, 1.894d+0, 0.057d+0, -0.279d+0,
     $                0.0d+0,0.0d+0/
#elif HAWI_harm
c NCEP monthly reanalysis data 88-99
c
      data c_ws   / 0.74433d+1,
     $              0.63265d-1,-0.59074d+0,-0.11762d+0, 0.30277d+0,
     $             -0.42812d+0,-0.16022d+0/
#elif defined HAWI_hali || defined HAWI_CDRGatm
c NCEP monthly reanalysis data 88-99 - without linear trend
cBX   update incl. 2001 data - 10JAN03
c
      data c_ws   / 0.74433d+1,
     $              0.63257d-1,-0.59071d+0,-0.11794d+0, 0.30269d+0,
     $             -0.42803d+0,-0.16067d+0/
#else
c NCEP monthly coefficients data from 1959 - 2000
c
       data c_ws   /  0.7531d+1,
     $                0.6781d+0, 0.1967d+1, 0.1809d+0, 0.1424d+0,
     $               -0.1997d+0,-0.1780d+0/   
#endif
c
#ifdef BATS_89_93
c BATS averaged ctd coefficients
c
      data c_h     / 0.74815d+2,
     $               0.4368d+2, 0.5597d+2, 0.2176d+2,-0.9656d+1,
     $              -0.3274d+0,-0.7658d+1/
#elif HAWI_harm
c mld data calculated from HOT data set - with linear trend
cBX   ctd data calculated with standard deviation
cBX   update incl. 2001 data - 10JAN03
      data c_h     / 0.60234d+2,
     $              -0.26665d+1, 0.26461d+2, 0.17475d+1, 0.13671d+2,
     $              -0.21122d+1, 0.23767d+1/
#elif defined HAWI_hali || defined HAWI_CDRGatm
c mld data calculated from HOT data set - without linear trend
cBX   ctd data calculated with standard deviation
cBX   update incl. 2001 data - 10JAN03
c
      data c_h     / 0.60294d+2,
     $              -0.31338d+1, 0.25574d+2, 0.22713d+1, 0.11109d+2,
     $              -0.13393d+1, 0.36606d+1/
#else
c
c BATS hydrographic data coefficients, BATS 1-156, updated May 3, 2002
c
       data c_h    /  0.7217d+2,
     $                0.4302d+2, 0.5158d+2, 0.2149d+2,-0.9637d+1,
     $               -0.1355d+1,-0.9183d+1/
#endif

