# 1 "func.F"
c =====================================================================
c
c     DOUBLE PRECISION FUNCTION FUNC
c
c     PURPOSE: this is the routine which calculates the value of
c                the cost function which is to minimize.
c              communication with the main program (for all the
c              the run parameters except those given through p
c              is done through common blocks, defined in
c              conj_grad_common.h
c     
c     VARIABLES:
c 
c     IN:   p            : input array of parameters
c     OUT:  func         : value of function at x
c
c     REVISIONS:
c 
c     date      author  remarks
c     
c     13.08.96   ng     first implementation
c 
c =====================================================================
c
      double precision function func(p)
c
c --------------------------------------------------------------------
c     global variables
c --------------------------------------------------------------------
c     
      implicit none
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/conj_grad.h" 1
c===================== include file conj_grad.h =========================
c
c variables for finding minimum using conjugate gradient technique
c
c REVISIONS:
c
c date     author    remarks
c
c 12.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c     
c assign         l  s   logical for subroutine assign_parameters
c                        true : assign values to parameters
c                        false: assign parameters to values   
c p             dp  a   array of parameters
c p_opt         dp  a   array of optimum parameters
c sg_p          dp  a   sigma of parameters
c p_init        dp  a   array of initial parameters
c nparams        i  s   dimension of parameters
c npmax          i  s   maximum dimension of p
c iter           i  s   number of iterations
c fret          dp  s   value of function at minimum
c hessian       dp  a   hessian matrix
c covm          dp  a   inverse of hessian matrix, covariance matrix
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      logical assign
      double precision ftol,fret
      integer nruns
      integer nparams,iter


      parameter(nparams = 10)










      double precision p(nparams),p_opt(nparams),p_init(nparams)
      double precision sg_p(nparams)
      double precision hessian(nparams,nparams),covm(nparams,nparams)
c
      
# 33 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/sg_params.h" 1
c===================== include file sg_params.h =========================
c
c variables defining special uncertainties
c
c REVISIONS:
c
c date     author    remarks
c
c 13.8.96  ng        first implementation
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c
c sg_c          dp  s   1-sigma uncertainty of C [umol kg-1]
c sg_dcdt       sp  s   1-sigma uncertainty of dcdt [umol kg-1 day-1]
c                          (estimated from figure)
c
c===========================================================================
c
      double precision sg_c,sg_dcdt
      parameter(sg_c = 2.d0, sg_dcdt = 0.02d0)
      
# 34 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/simulation.h" 1
c======================= include file simulation.h ==========================
c
c variables for controlling the simulation
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 15.10.99 ng        adapted for interannual variability runs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c tstart        dp s   start time of simulation  [decimal year]
c tend          dp s   end time of simulation    [decimal year]
c ts            dp s   time step of simulation   [decimal year]
c nstepmax      dp s   maximum number of steps  
c nstep         i  s   number of steps
c time          dp s   actual time               [decimal year] 
c
c-------------------------------------------------------------------------
c
      double precision tstart,tend,ts,time
      integer nstep,nstepmax
c
      parameter (nstepmax = 10000)



# 35 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/gasex_params.h" 1
c===================== include file gasex_params.h =========================
c
c parameters of air-sea exchange
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 06.6.00  ng        added comp_foc2_online
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c 
c pv_relship     c  s   character indicating the relationship between
c                       piston velocity and wind-speed that is used for
c                       calculating the piston-velocity
c                           <lm> : Liss and Merlivat
c                           <wa> : Wanninkhof  
c D_fco2_corr    dp s   correction term for calculated fCO2 ocean     [uatm]
c gasex_fact     dp s   multiplication factor for air-sea exchange
c                           usually 1.0 for Wanninkhof
c                           usually 1.7447 for Liss and Merlivat
c
c ws_coeff       c  s   character specifying wind speed coefficients
c                           <ih> : Isemer and Hasse, 1985
c                           <ae> : AEROCE, 1989-1991
c
c sg_D_fco2_corr dp a   uncertainty of D_fco2_corr
c sg_gasex_fact  dp a   uncertainty of gasex_fact
c
c mean_air_press dp s   mean air pressure [atm] (from St. Davids head)
c mean_rel_humid dp s   mean relative humidity [] (from St. Davids head)
c 
c comp_fco2_online l s  logical indicating whether fco2 should be
c                         computed on or offline
c
c===========================================================================
c
      character pv_relship*2,ws_coeff*2
      double precision D_fco2_corr,gasex_fact
      double precision sg_D_fco2_corr, sg_gasex_fact
c
      double precision mean_air_press,mean_rel_humid




      parameter (mean_air_press = 1.017,mean_rel_humid = 0.87)

c
      logical comp_fco2_online
# 36 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diffent_params.h" 1
c===================== include file diffent_params.h =========================
c
c parameter of vertical diffusion and entrainment
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 09.9.96  ng        included const_lent
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c ent_scheme      c  s   character indicating entrainment scheme to be used
c                            <in> : integrated vertical gradient scheme (DEF)
c                            <mc> : mass conservation scheme
c                            <ep> : episodic event scheme
c                            <ma> : matear scheme
c                        the <in> scheme is the new scheme developed by ng
c                                      for station BATS
c                        the <mc> scheme is the scheme of Thomas Stocker
c                                      with the assumption that the 
c                                      concentrations at a specified depth
c                                      remain constant
c                        the <ep> scheme is the original scheme developed by
c                                      C.D. Keeling used in the station 'S'
c                                      study
c                        the <ma> scheme is the scheme used by Matear (1995)
c                                      in his model (uses an entrainment
c                                      length scale)
c h_coeff         c  s   character specifying which coefficients for
c                            mixed layer depth coefficients should be taken
c                            <b> : bats          <s> : station S  
c                            <c> : bats CTD      <a> : bats avg CTD 
c                 
c dt_ent_re      dp  s   recurrence period of entrainment (only important
c                            for the <ep> scheme
c const_Kz        l  s   logical indicating whether const Kz is used or
c                            seasonally varying Kz
c kz_const       dp  s   value of constant kz [m2 s-1]
c const_vertgrad  l  s   logical indicating whether const vertical gradients
c                            are used or seasonally varying
c dCdz_const     dp  s   value of constant dCdz [umol kg-1 m-1]
c D_dcdz         dp  s   correction term for dCdz [umol kg-1 m-1]
c dd13C_dC_bml   dp  s   ratio of ddC13/dz and dC/dz below mixed layer
c                           [per mil kg umol-1]
c diff_fact      dp  s   multiplication factor for vertical diffusion
c ent_fact       dp  s   multiplication factor for entrainment
c h_th           dp  s   depth at which thermocline values for mc entrainment
c                           scheme are taken
c c_th           dp  s   C concentration at h_th [umol kg-1]
c dC13_th        dp  s   dC13 concentration at h_th [per mil]
c 
c const_lent     dp  l   logical indicating use of a constant ent_length
c lent_const     dp  s   constant entrainment length scale 
c                                (for Matear entrainment) [m]
c dlent_dh       dp  s   slope of ent length vs h [no units]
c
c sg_ddC13_dC_bml dp  s   sigma uncertainty of dd13C_dC_bml (for OP and MC)
c sg_diff_fact    dp  s   sigma uncertainty of diff_fact (for OP and MC)
c sg_ent_fact             sigma uncertainty of ent_fact (for OP and MC)
c sg_kz_const     dp  s   sigma uncertainty of kz (for OP and MC)
c sg_lent_const   dp  s   sigma uncertainty of ent_length (for OP and MC)
c sg_D_dcdz       dp  s   sigma uncertainty of dcdz
c                
c=============================================================================
c
      character ent_scheme*2,h_coeff*1
      logical const_kz,const_vertgrad,const_lent
      double precision dt_ent_re
      double precision kz_const,dCdz_const,D_dcdz
      double precision ddC13_dC_bml,diff_fact,ent_fact
      double precision h_th,C_th,dC13_th
      double precision lent_const,dlent_dh
c
      double precision sg_ddC13_dC_bml
      double precision sg_ent_fact,sg_diff_fact
      double precision sg_kz_const,sg_lent_const,sg_D_dcdz
      double precision sg_dlent_dh
      
# 37 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/adv_params.h" 1
c===================== include file adv_params.h =========================
c
c parameters of horizontal advection
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c 17.10.99 ng        added dC13_dh
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c dC_dh          dp  s   horizontal C gradient       [umol kg-1 m-1] 
c ddC13_dh       dp  s   horizontal dC13 gradient    [per mil m-1]
c dC13_dh        dp  s   horizontal C13 gradient     [umol kg-1 m-1] (calc)
c u              dp  s   horizontal velocity         [m s-1]
c
c sg_dC_dh       dp  a   1-sigma uncertainty for dC_dh (for OP and MC)
c sg_ddC13_dh    dp  a   1-sigma uncertainty for ddC13_dh (for OP and MC)
c sg_u           dp  a   1-sigma uncertainty for u (for OP and MC)
c 
c=============================================================================
c
      double precision dC_dh,ddC13_dh,dC13_dh
      double precision u
      double precision sg_dC_dh,sg_ddC13_dh
      double precision sg_u
# 38 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/ncp_params.h" 1
c===================== include file ncp_params.h =========================
c
c parameters of net community production
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 13.8.96  ng        changed l_* to sg_*
c
c variables:
c
c name            type   description
c-----------------------------------------------------------------------------
c                 
c D_dC13_org      dp s   correction term for dC13 value of organic matter
c dc13_org        dp s   dc13 value of organic matter
c                         [per mil]
c sg_D_dc13_org   dp s   1 sigma uncertainty of D_dc13_org (for OP and MC)
c 
c=============================================================================
c
      double precision D_dc13_org
      double precision sg_D_dc13_org
      double precision dc13_org
# 39 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/conj_grad_common.h" 1
c================ include file conj_grad_common.h =========================
c
c special include block for subroutine func.F. You find here all
c   parameters which are necessary to run the simulation, except for
c   the parameters that are optimized by the conjugate gradient 
c   technique. for variable definitions see *_params.h file
c
c REVISIONS:
c
c date     author    remarks
c
c 12.8.96  ng        first implementation
c  9.9.96  ng        included new definition of entrainment length
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c   
c
c===========================================================================
c
      common/sim/tstart,tend,ts,nstep
c
      common/ex/D_fco2_corr,gasex_fact,pv_relship
c
      common/coeff/dc13_coeff,h_coeff,ws_coeff
c
      common/diffent/
     $     dt_ent_re,lent_const,dlent_dh,
     $     ent_fact,diff_fact,
     $     kz_const,dcdz_const,
     $     h_th,c_th,dc13_th,ddc13_dc_bml,
     $     const_vertgrad,const_kz,const_lent,
     $     ent_scheme
c
      common/adv/dc_dh,ddc13_dh,u,incl_adv
c
      common/ncp/D_dc13_org
c
      common/conjgrad/sg_p,p_init
      
# 40 "func.F" 2
c
c --------------------------------------------------------------------
c     variables to communicate with run_simulation
c --------------------------------------------------------------------
c 
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/diagboxmod.h" 1
c===================== include file diagboxmod.h =========================
c
c general variables of diagnostic box model
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c  2.9.96  ng        included inverse mode
c
c variables:
c
c name          type   description
c---------------------------------------------------------------------------
c               
c exp_name      c  s   name of experiment 
c notes         c  s   notes to add to experiment on output
c sim_mode      c  s   character specifying simulation mode
c                       <st>  : standard simulation
c                       <mc>  : monte carlo simulation
c                       <op>  : parameter optimization
c                       <sn>  : sensitivity mode
c                       <in>  : inverse calculation of u and dC13/dx
c sol_scheme    c  s    <std> : original standard, solving for dC/dt
c               c  s    <adv> : solve for u velocity
c               c  s    <phy> : solve for Kz + u
c               c  s    <kz>  : solve for Kz
c
c dc13_coeff    c  s   character specifying which dc13 coefficients are
c                        used
c                       <o1>  : original data with harmonic fit of 1st order
c                       <o2>  : original data with harmonic fit of 2nd order
c                       <a2>  : artificial curve with 2nd order harm fit
c def_par       l  s   logical specifying use of default parameters for run
c incl_adv      l  s   logical specifying whether advection is included
c                        or not
c plot_out      l  s   logical indicating that plots should be generated
c
c===========================================================================
c
      character exp_name*10,notes*30,dc13_coeff*2
      logical def_par,incl_adv,plot_out
      character sim_mode*2,sol_scheme*3
      
# 46 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/processes.h" 1
c======================= include file processes.h ============================
c
c variables for the processes that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nproc_fluxes      i  s   number of processes for the fluxes
c nproc_rates       i  s   number of processes for the rates of change
c proc_fluxes_name  c  a   array holding the names of the flux processes
c proc_rates_name   c  a   array holding the names of the rates processes
c  
c------------------------------------------------------------------------
c
      integer nproc_fluxes,nproc_rates
      parameter(nproc_fluxes = 10, nproc_rates = 7)
c
      character proc_fluxes_name(nproc_fluxes)*4
      character proc_rates_name(nproc_rates)*4
c
      data proc_rates_name  /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs '/
      data proc_fluxes_name /'ex  ','diff', 'ent ', 'adv ', 'ncp ',
     $                       'sim ','obs ', 'zcmp', 'tcal', 'tobs'/



      

# 47 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/periods.h" 1
c======================= include file periods.h ==============================
c
c variables for the periods that are investigated 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        adapted for interannual runs, periods are replaced with
c                       years
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c nyears        i  s   number of years to analyze
c year_start    dp a   start of analysis year
c 
c  
c------------------------------------------------------------------------
c
      integer nyearmax,nyears
      parameter(nyearmax = 20)
c
      double precision year_start
c
      data year_start / 0.0 /



      

# 48 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/intval.h" 1
c
c======================= include file intval.h ==============================
c
c variables for calculating the time integrated fluxes and changes
c in concentrations. 
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c 17.10.99 ng        changed nperiods to nyears
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c Int_Fluxes    dp a   two dimensional array holding the time integrated
c                       fluxes over the mixed layer.
c                       unit: molC/m2 
c
c Int_Rates     dp a   two dimensional array holding the time integrated
c                       rates of change
c                       unit: umolC/kg 
c-------------------------------------------------------------------------
c
      double precision Int_Fluxes(nyearmax,nproc_fluxes)
      double precision Int_Rates(nyearmax,nproc_rates)



# 49 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/slabs.h" 1
c======================== include file slabs.h  =============================
c
c main variables for the seasonal carbon model:
c
c REVISIONS:
c
c date     author    remarks
c
c 31.7.96  ng        first implementation
c
c variables:
c
c name       type  description                                   units
c-----------------------------------------------------------------------------
c
c C_new      dp s  obs DIC at time step t+ts                     muM/kg
c C_old      dp s  obs DIC at time step t                        muM/kg
c C          dp s  obs DIC at time step t+0.5*t                  muM/kg
c C_obs      dp a  array of observed DIC                         muM/kg
c C_sim      dp a  array of simulated DIC                        muM/kg
c	    
c C13_new    dp s  obs. C13 at time step t+ts                    muM/kg
c C13_old    dp s  obs. C13 at time step t                       muM/kg
c C13        dp s  obs. C13 at time step t+0.5*ts                muM/kg
c dC13_obs   dp a  array of observed dC13                        per mil
c      	     
c h_new      dp s  mixed layer depth at time step t+ts           m
c h_old      dp s  mixed layer depth at time step t              m
c h          dp s  mixed layer depth at time step t+0.5*ts       m
c h_obs      dp a  array of observed mixed layer depths          m
c
c D_C        dp a   Delta C due to the different processes       muM/kg/ts
c                    DDIC(nproc_rates,ts)
c D_C13      dp a   Delta C13 due to the different processes     per mil/ts
c                    DdC13(nproc_rates,ts)
c fluxes     dp a   Flux of DIC due to the different processes   mol C/m2/s
c                    Flux(nproc_fluxes,ts)
c
c-----------------------------------------------------------------------------
c
      double precision C_old,C_new,C13_old,C13_new,h_new,h_old
      double precision C,c13,h
      double precision C_obs(nstepmax),C_sim(nstepmax)
      double precision dC13_obs(nstepmax),h_obs(nstepmax)
c
      double precision D_C(nproc_rates,nstepmax)
      double precision D_C13(nproc_rates,nstepmax)
      double precision fluxes(nproc_fluxes,nstepmax)


# 50 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/obs_values.h" 1
c==================== include file obs_values.h  =============================
c
c observed seasonal cycles of input data 
c    (except C, dC13 and h which are defined in slabs.h)
c
c REVISIONS:
c
c date     author    remarks
c
c 08.08.96  ng       first implementation
c 07.06.00  ng       added salk_obs
c
c variables:
c
c name       type   description                                   units
c-----------------------------------------------------------------------------
c
c temp_obs     dp a  mixed layer temperature                       deg C
c sal_obs      dp a  mixed layer salinity                          psu
c ws_obs       dp a  wind-speed                                    m s-1
c fco2_o_obs   dp a  CO2 fugacity in the mixed layer               uatm
c pco2_a_obs   dp a  xco2 in the atmosphere
c fco2_a_obs   dp a  fCO2 in the atmosphere                        uatm
c pco2_a_dry   dp a  pCO2 in the atmosphere                        
cc dc13_a_obs   dp a  dC13 in the atmosphere                        per mil
c dCdz_obs     dp a  vertical C gradient below the mixed layer     umol/kg/m
c kz_obs       dp a  vertical diffusivity                          m2 s-1
c salk_obs     dp a  salinity normalized alk                       umol/kg
c 
c-----------------------------------------------------------------------------
c
      double precision temp_obs(nstepmax),sal_obs(nstepmax)
      double precision ws_obs(nstepmax),fco2_o_obs(nstepmax)
      double precision pco2_a_obs(nstepmax),fco2_a_obs(nstepmax)
      double precision pco2_a_dry(nstepmax)
      double precision dc13_a_obs(nstepmax)
      double precision dCdz_obs(nstepmax),kz_obs(nstepmax)
      double precision salk_obs(nstepmax)


# 51 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/statistics.h" 1
c==================== include file statistics.h ==============================
c
c variables for the run statistics
c
c REVISIONS:
c
c date     author    remarks
c
c 08.8.96  ng        first implementation
c 05.9.96  ng        included c_min,c_max,c_min_obs,c_max_obs
c
c variables:
c
c name          type   description
c-----------------------------------------------------------------------------
c 
c chisq         dp s   chi**2 between simulated and observed rate of change
c rsq           dp s   r**2 of fit between simulated and observed rates
c closure       dp s   annual lack of closure
c amplitude     dp s   simulated annual amplitude
c amplitude_obs dp s   observed annual amplitude
c c_min         dp s   simulated minimum C
c c_max         dp s   simulated maximum C
c c_min_obs     dp s   observed minimum C
c c_max_obs     dp s   observed maximum C
c par_sum       dp s   value of parameter misfit
c costfn        dp s   value of cost function
c chisq_term    dp s   value of chi**2 term in cost function
c clos_term     dp s   value of closure term in cost function
c ampl_term     dp s   value of amplitude term in cost function
c par_term      dp s   value of parameter term in cost function
c
c-------------------------------------------------------------------------
c
      double precision chisq,rsq,closure,costfn,amplitude
      double precision amplitude_obs,par_sum
      double precision c_min,c_max,c_min_obs,c_max_obs
      double precision chisq_term,clos_term,ampl_term,par_term



# 52 "func.F" 2
# 1 "/usr/local/abies/home/brix/tmp/diag_boxmod_syn/src_ia/incl/averages.h" 1
c======================= include file averages.h ==============================
c
c variables for calculating annual averages
c
c REVISIONS:
c
c date     author    remarks
c
c 31.07.96  ng        first implementation
c 10.09.96  ng        included dC13 values for different processes
c
c variables:
c
c name           type   description
c-----------------------------------------------------------------------------
c 
c sum_fract     dp  s   sum for calculating average fractionation factor
c sum_kex       dp  s   sum for calculating average kex
c sum_dCdz      dp  s   sum for calculating average vertical DIC gradient
c sum_ddC13dz   dp  s   sum for calculating average vertical dC13 gradient
c sum_dC13_prc  dp  a   sum for calculating average dC13 values of the proc
c nsum_dc13_prc  i  a   number of values used for summing sum_dc13_prc
c
c avg_fract     dp  s   average fractionation factor [per mil]
c dc13_prc      dp  a   average dc13 value of the processes [per mil]
c avg_kex       dp  s   average kex value [mol m-2 s-1 uatm-1]
c
c-------------------------------------------------------------------------
c
      double precision sum_fract,sum_kex,sum_dCdz,sum_ddC13dz
      double precision avg_fract,avg_kex
      double precision sum_dC13_prc(4)
      integer nsum_dc13_prc(4)
      double precision dc13_prc(4)



# 53 "func.F" 2
      logical error
c
c --------------------------------------------------------------------
c     local variables
c --------------------------------------------------------------------
c 
      integer np
c
c --------------------------------------------------------------------
c     external functions
c --------------------------------------------------------------------
c 
      double precision cost_function
c
c =====================================================================
c     begin of executable code
c =====================================================================
c
c
c --------------------------------------------------------------------
c     info
c --------------------------------------------------------------------
c 
c      write(*,*) '--FUNC: calling run_simulation '
c      write(*,*) '    parameter values : '
c      do np = 1,nparams
c         write(*,*) '    np,p(np) : ',np,p(np)
c      enddo
c      write(*,*) 'incl_adv : ',incl_adv
c      write(*,*) 'const_lent : ',const_lent
c
c --------------------------------------------------------------------
c     assign conjugate gradient parameter values to regular parameters
c --------------------------------------------------------------------
c 
      assign = .false.
      call assign_params(assign,
     $     gasex_fact, sg_gasex_fact,
     $     D_fco2_corr,sg_D_fco2_corr,
     $     diff_fact,sg_diff_fact,D_dcdz,sg_D_dcdz,
     $     ddC13_dC_bml,sg_ddC13_dC_bml,
     $     const_lent,lent_const,sg_lent_const,
     $     dlent_dh,sg_dlent_dh,   
     $     D_dc13_org,sg_D_dc13_org, 
     $     u,sg_u,dc_dh,sg_dc_dh,ddC13_dh,sg_ddC13_dh,   
     $     p,sg_p,p_init) 
c
c --------------------------------------------------------------------
c     run the simulation
c --------------------------------------------------------------------
c 
c      write(*,*) '--FUNC: calling simulation...'
c
         call run_simulation(
     $     tstart,tend,ts,nstep,
     $     dc13_coeff,
     $     pv_relship,D_fco2_corr,gasex_fact,ws_coeff,      
     $     ent_scheme,h_coeff,
     $     h_th,c_th,dc13_th,
     $     dt_ent_re,const_lent,lent_const,dlent_dh,ent_fact,
     $     const_Kz,Kz_const,
     $     const_vertgrad,dCdz_const,D_dcdz,
     $     ddC13_dC_bml,diff_fact,
     $     incl_adv,dC_dh,ddC13_dh,u,
     $     D_dc13_org,
c
     $     D_c,D_c13,fluxes,
     $     c_obs,dc13_obs,h_obs,
     $     temp_obs,sal_obs,
     $     fco2_o_obs,pco2_a_obs,fco2_a_obs,
     $     dc13_a_obs,ws_obs,dcdz_obs,kz_obs,
     $     c_sim,
     $     int_rates,int_fluxes,
     $     chisq,rsq,closure,amplitude,amplitude_obs,
     $     c_min,c_max,c_min_obs,c_max_obs,costfn,
     $     avg_fract,dc13_prc,avg_kex,
     $     error)
c
c --------------------------------------------------------------------
c     calculate cost function : part of parameter deviation
c -------------------------------------------------------------------- 
c
         par_sum = 0.d0
         do np = 1,nparams
            par_sum = par_sum + p(np)**2
c            par_sum = par_sum + ((p(np) - p_init(np))/sg_p(np))**2
         enddo
c
c --------------------------------------------------------------------
c     calculate total cost function
c --------------------------------------------------------------------
c 
         func = cost_function(chisq,closure,par_sum,nparams,
     $        amplitude,amplitude_obs,
     $        c_min,c_max,c_min_obs,c_max_obs,
     $        chisq_term,clos_term,par_term,ampl_term)
c
c
c
c --------------------------------------------------------------------
c     return to main program
c --------------------------------------------------------------------
c     
      return

      end











